Security Advisories (1)
CPANSA-Catalyst-Runtime-2013-01 (2013-01-23)

Passing a special host to the redirect page link makes it vulnerable to XSS attack.

NAME

Catalyst::ClassData - Class data accessors

METHODS

mk_classdata $name, $optional_value

A moose-safe clone of Class::Data::Inheritable that borrows some ideas from Class::Accessor::Grouped;

AUTHOR

Guillermo Roditi

COPYRIGHT

This library is free software. You can redistribute it and/or modify it under the same terms as Perl itself.